@@ -60,10 +60,4 @@ int writeBytesSocketConn(char* command);
 int readSocketConn(char* buffer, int len);
 int sendKeepAlive(void);
 
-// Frontend support
-int connectFrontEnd(int portno);
-int sendToFrontEnd(char *buf);
-int disconnectFrontEnd(void);
-int readFromFrontEnd(char *buf, int size);
-
 #endif
