@@ -27,6 +27,7 @@
 #define EXIT_OK      0
 #define EXIT_DISCON  2
 #define EXIT_ABORT   3
+#define EXIT_STOP    4
 
 #define MAXMAXLEN    	2048
 #define MAXLEN          512
@@ -46,14 +47,14 @@
 
 #define TOFILE   	"/anyremote.cmd.results"
 
-#define CLIENT_AT       0
-#define SERVER_TCP      1
-#define SERVER_BT       2
-#define CLIENT_ILIRC    3
-#define SERVER_UX       4
-#define CLIENT_NOAT     5
-#define SERVER_STDIN    6
-#define SERVER_L2CAP    7
+#define CLIENT_AT       0	// AT protocol
+#define SERVER_TCP      1	// anyRemote protocol over TCP/IP
+#define SERVER_BT       2	// anyRemote protocol over btspp
+#define CLIENT_ILIRC    3	// inputLirc protocol
+#define SERVER_UX       4       // NOT USED: anyRemote protocol over IR (or any AF_UNIX socket) - as server
+#define CLIENT_NOAT     5	// anyRemote protocol over IR (or any AF_UNIX socket) - as client
+#define SERVER_STDIN    6	// anyRemote protocol, read command from stdin
+#define SERVER_L2CAP    7	// anyRemote protocol over l2cap
 
 #define DEFAULT_BT_CHANNEL 19
 #define DEFAULT_L2CAP_PORT 5019
