@@ -46,6 +46,7 @@
 #include "utils.h"
 #include "xemulate.h"
 
+#include "pr_frontend.h"
 #ifdef USE_L2CAP
 	#include "pr_l2cap.h"
 #endif
@@ -60,6 +61,7 @@ static void mainRoutine     (void);
 static int  isBemusedCommand(char *cmd);
 static int  isInpLircCommand(char *cmd);
 static int  isLircCommand   (char *cmd);
+static int  isIViewerCommand(char *cmd);
 
 char tmp	    [MAXMAXLEN];
 char callerId	    [MAXLEN];
@@ -100,7 +102,7 @@ int openPort(char * portIn)
         // 3. (Server mode) bluetooth:NN or bluetooth (port will be = DEFAULT_BT_CHANNEL) 	used with java client
         // 4. local:/some/path									used with java client, like 1, but no AT commands
         // 5. ilirc:/dev/something 								like 1, but no AT commands
-        // 6. stdio								used with java client, like 1, but no AT commands
+        // 6. stdio								                used with java client, like 1, but no AT commands
 
         if ((strPort = strstr(portIn, INET_SOCKET)) != NULL) {
         	
@@ -228,6 +230,7 @@ int openPort(char * portIn)
                 	logger("INFO", "Exec cmd on init");
                         handleCmdByKey(k,NULL);  // Since we not connected yet we did not interested in return code
                 }
+		handleHook(ID_EVT_INIT);
                 initialized++;
         }
 	
@@ -298,6 +301,7 @@ static void freeAndExit(void)
 		logger("INFO", "Exec cmd on exit");
 		handleCmdByKey(k,NULL);   // Since we exiting now we did not interested in return code
 	}
+	handleHook(ID_EVT_EXIT);
 	
         if (serverMode == SERVER_BT) {
 		sdpDeregister();
@@ -372,9 +376,6 @@ int main(int argc, char *argv[])
         } else if (argv[1] && (strcmp(argv[1],"-v")==0 || strcmp(argv[1],"--version")==0)) {
 		printf("anyremote v%s\n", PACKAGE_VERSION); 
 		exit(0);
-        //} else if (argv[1] && strcmp(argv[1],"-getconfdir")==0) {
-	//	 printCfgDir();
-	//         exit(0);
         }
 
         if (init_cfg(i<argc ? argv[++i] : NULL) != EXIT_OK) {
@@ -394,6 +395,8 @@ int main(int argc, char *argv[])
 
         createDataDir();
         initLog();
+	
+	addInternalVars();
         
         // Not to core dump if connection will close
         signal(SIGPIPE, SIG_IGN);   
@@ -539,6 +542,9 @@ int handle_command(char* cmd)
 	if (next == NULL && serverMode != CLIENT_AT) {	// Java client will send +CKEV: 1,1; +CKEV: 1,0
 		next = strchr(cmd, ';');
 	}
+	if (next == NULL && serverMode != CLIENT_AT) {
+		next = strchr(cmd, '\3');		// end-of-text marker in CommandFusion
+	}
 	if (next) {
 		logger("DEBUG", "handle_command() multiline");
 
@@ -548,7 +554,7 @@ int handle_command(char* cmd)
 		do {	 
 			len = next-prev;
 	
-			if (len > 2) {
+			if (len >= 2) {
 				memcpy(copy, prev, len);
 				copy[len] = 0;
 			
@@ -563,6 +569,9 @@ int handle_command(char* cmd)
 			if (next == NULL && serverMode != CLIENT_AT) {	// Java client will send +CKEV: 1,1; +CKEV: 1,0
 				next = strchr(prev, ';');
 			}
+			if (next == NULL && serverMode != CLIENT_AT) {	
+				next = strchr(prev, '\3');		// end-of-text marker in CommandFusion
+			}
 		} while (next) ;
 
 		// now return
@@ -697,7 +706,9 @@ int handle_command(char* cmd)
 		return EXIT_OK;
 	} else if (isBemusedCommand(cmd)) {	    // Bemused server emulation tricks
 		return EXIT_OK;
-	} else if (serverMode == SERVER_STDIN) {    // Just direct input, try it
+	} else if (isIViewerCommand(cmd)) {	    // CommandFusion iViewer protocol support
+		return EXIT_OK;
+	} else /*if (serverMode == SERVER_STDIN)*/ {    // Just direct input, try it
         	//printf("DEBUG: Is it SERVER_STDIN ? %s\n", cmd);
                 
                 char *p = cmd;
@@ -932,26 +943,111 @@ static void mainRoutine(void)
 			
                         isConnected = 1;
                         
+			if (usePassword()) {
+				int PassOk = 0;
+				
+				char *pass = getStoredPass();
+				
+				if (pass) {
+				
+					if (fe > 0) {
+						sendToFrontEnd("Verifying password");
+					}
+					
+					ret = writeSocketConn("Get(password);", 14);
+	    		    		if (ret == EXIT_ABORT) {
+						free(pass);
+						freeAndExit();      // Exit here
+	    		    		} else if (ret == EXIT_DISCON) {
+						free(pass);
+						if (fe > 0) {
+						isConnected = 0;
+							sendToFrontEnd("Disconnected");
+						}
+	    					continue;
+	    		    		}
+					
+					while (1) {
+						retRead = read_command(answer, sizeof(answer));
+				
+						if (retRead == EOF) {
+							if (fe > 0) {
+								sendToFrontEnd("Disconnected");
+							}
+							break;
+						} else if (retRead > 0) {
+							DEBUG2("Password => %s\n",answer);
+							DEBUG2("Password => %s\n",answer+16);
+							DEBUG2("Compare to => %s\n",pass);
+				
+							if (memcmp(answer,   DEF_MSG, 4) == 0 && 
+				    	                    memcmp(answer+4, "_PASSWORD_(,", 12) == 0) {	    // Got verification response from Java client
+						
+								if (memcmp(answer+16, pass, strlen(pass)) == 0) {
+									logger("DEBUG","Password OK");
+									PassOk = 1;
+								} else {
+									logger("DEBUG","Verification failed. Incorrect password.");
+									if (fe > 0) {
+										sendToFrontEnd("Verification failed");
+									}
+								}
+							
+							} else {
+								logger("DEBUG","Verification failed. Incorrect response.");
+								if (fe > 0) {
+									sendToFrontEnd("Verification failed");
+								}
+							}
+							break;
+						}
+						usleep(50000);
+					}
+				} else {
+					logger("DEBUG","No password specified. Skip check.");
+				}
+				
+				free(pass);
+				if (PassOk == 0) {
+				        writeSocketConn("Set(title,PASSWORD INVALID);", 28);
+					
+					sleep(1);
+					
+					closePort(1);
+					isConnected = 0;
+					
+					sleep(5);
+					continue;	
+				}
+			}
+			
 			if (fe > 0) {
 				sendToFrontEnd("Connected");
 			}
-	    	
-			i = 0;    
+		        
+			i = 0;
+			int ok1 = EXIT_NOK;    
 	    		k = findItem(EVT_CONNECT, &i, NULL);
 			if (k && i == FLAG_EXACT) {
 		    		logger("INFO", "Exec cmd on connect");
-				//printf("mainRoutine: Exec cmd on connect\n");
+				ok1 = EXIT_OK;
+
 		    		ret = handleCmdByKey(k,NULL);
-		    		if (ret == EXIT_ABORT || ret == EXIT_DISCON) {
-				        printf("mainRoutine: Exec cmd on connect EXIT_ABORT/EXIT_DISCON \n");
+		    		if (ret == EXIT_ABORT) {
+			        	printf("mainRoutine: Exec cmd on connect EXIT_ABORT\n");
 					return;
+		    		} else if (ret == EXIT_DISCON) {
+			        	printf("mainRoutine: Exec cmd on connect EXIT_DISCON\n");
+					continue;
 		    		}
+			}
+			int ok2 = handleHook(ID_EVT_CONNECT);
+			
+			if (ok1 == EXIT_OK || ok2 == EXIT_OK) {
 				if (getHttp()) {
 					writeSocketConn("End();", 6);
 				}
 			}
-			
-			//printf("mainRoutine: connect OK\n");
 
 			logger("INFO","Start event forwarding");
 		
@@ -980,7 +1076,8 @@ static void mainRoutine(void)
 			    			ret = handleCmdByKey(k,NULL);
 	    		    			// No additional handling since we already disconnected
 					} 
-
+					handleHook(ID_EVT_DISCONNECT);
+					
 					if (gotSignal) {
 			   	 		logger("INFO", "Got signal, exiting");
 						closePort(1);
@@ -1008,7 +1105,7 @@ static void mainRoutine(void)
 	    		
 	    				break;
 		    		} else if (retRead > 0) {
-					DEBUG2("-------------------- Command read --------------------");
+					logger("DEBUG","-------------------- Command read --------------------");
 	    	    
 		    			if (serverMode == CLIENT_NOAT) {	// in IR communication a lot of 'empty' chars (= -1) could be added
 						char * k2 = answer;
@@ -1098,10 +1195,15 @@ static void mainRoutine(void)
 	    				}
 	    	    		}
 
-		    		// Verify commands executed by timer (timeout about 1/2 sec)
-	    	    		if (commandTimer == 10) {
+		    		// Verify commands executed by timer (timeout about 1 sec)
+	    	    		if (commandTimer == 20) {
 	    				//logger("DEBUG","Verify timer commands ...");
 	    				ret = verifyTimers(1) ;
+	    		    		if (ret == EXIT_ABORT) {
+						freeAndExit();      // Exit here
+	    		    		} else if (ret == EXIT_DISCON) {
+	    					break;
+	    		    		}
 	    				commandTimer = 0;
 					
 	    	    		} else {
@@ -1367,15 +1469,15 @@ static int isLircCommand(char *cmdIn)
 	free(cmd);
         return 1;
 }  
+
 //
 // inputlirc dev/event handling
 //
-
 static int isInpLircCommand(char *cmdIn)
 {  
 	// should got replay in form "2 0 KEY_1 event6"
 	
-	DEBUG2("isLircCommand: >%s<",cmdIn);
+	DEBUG2("isInputLircCommand: >%s<",cmdIn);
 
 	/*char *f = cmdIn;
 	sprintf(tmp, "isLircCommand: DUMP >%c< >%d<",*f,*f);
@@ -1418,3 +1520,76 @@ static int isInpLircCommand(char *cmdIn)
 	free(cmd);
         return isLirc;
 }
+
+//
+// Command Fusion iViewer protocol support
+//
+static int isIViewerCommand(char *cmdIn)
+{  
+	// should got replay in form
+        // aXX=value\3
+        // dXX=value\3
+        // h=0\3
+        // i=1\3
+        // lXX=value\3	-- not yet supported
+        // m=[portrait|landscape]\3
+        // p=value\3
+        // sXX=value\3
+	
+	DEBUG2("isIViewerCommand: >%s<",cmdIn);
+        
+        char* cmdTmp = calloc(strlen(cmdIn) + 1, sizeof(char));        
+        strcpy(cmdTmp,cmdIn);
+        
+        if (!((cmdTmp[0] == 'a' && isdigit(cmdTmp[1])) ||
+              (cmdTmp[0] == 'd' && isdigit(cmdTmp[1])) ||
+              (cmdTmp[0] == 'l' && isdigit(cmdTmp[1])) ||
+              (cmdTmp[0] == 's' && isdigit(cmdTmp[1])) ||
+              (cmdTmp[0] == 'm' && cmdTmp[1] == '=')   ||
+              (cmdTmp[0] == 'p' && cmdTmp[1] == '=')   ||
+              strcmp(cmdTmp, "h=0") == 0 ||
+              strcmp(cmdTmp, "i=1") == 0 
+            )) {
+		free(cmdTmp);
+		return 0;
+	} 
+        
+        char *bufPtr = NULL;
+        char *token = strtok_r(cmdTmp,"=",&bufPtr);
+	if (token == NULL) {
+		free(cmdTmp);
+		return 0;
+	}
+        token = strtok_r(NULL,"=",&bufPtr);
+
+        DEBUG2("isIViewerCommand: OK >%d<", (int) strlen(cmdIn) + 6);
+
+        char* cmd = calloc(strlen(cmdIn) + 6, sizeof(char));
+        strcpy(cmd,cmdTmp);
+        
+        strcat(cmd,"(");
+        if (cmdTmp[0] == 'm' || 
+	    cmdTmp[0] == 'p' || 
+	    cmdTmp[0] == 's') {
+	    
+        	strcat(cmd,"-1,");
+        	if (token != NULL) {
+                	strcat(cmd,token);      // token is string
+        	}
+
+                strcat(cmd,")");
+        } else {
+        	if (token != NULL) {
+        		strcat(cmd,token);	// token is numeric
+        	}
+        	strcat(cmd,",)");
+        }
+	free(cmdTmp);
+
+        DEBUG2("isIViewerCommand: one commmand >%s<", cmd);
+	handle_key_press(cmd,1);
+	
+	logger("INFO", "isIViewerCommand: EXIT");	
+	free(cmd);
+        return 1;
+}
