@@ -44,16 +44,16 @@
 #include <regex.h>
 
 #define REGEX_KEYVAL   "^[[:space:]]*(\\[[[:alpha:]]+\\])([^=]*)$|^[[:space:]]*([^=%]*[^[:space:]]{1})[[:space:]]*=[[:space:]]*(.*[^[:space:]]{1})[[:space:]]*$"
-#define REGEX_CMDBYCMD "[[:space:]]*(Exec|ExecAndSet|Make|SetMode|Get|Set|Send|ExecAndSend|Timer|CancelTimer|Macro|Load|Include|SendCKPD|Emulate)[[:space:]]*(\\()|[[:space:]]*(Exit)[[:space:]]*;{0,1}"
+#define REGEX_CMDBYCMD "[[:space:]]*(Exec|ExecAndSet|Make|Get|Set|Send|ExecAndSend|Timer|Macro|Load|Include|SendCKPD|Emulate)[[:space:]]*(\\()|[[:space:]]*(Exit)[[:space:]]*;{0,1}"
 
 #define REGEX_SET    "[[:space:]]*(bg|editfield|filemanager|fg|font|fullscreen|icons|list|iconlist|menu|parameter|skin|status|text|title|volume|image|cover|var)[[:space:]]*,[[:space:]]*(.*)|[[:space:]]*(vibrate|repaint|disconnect)[[:space:]]*"
-#define REGEX_GET    "[[:space:]]*(screen_size|cover_size|model|version|cursor)[[:space:]]*|[[:space:]]*(is_exists)[[:space:]]*,[[:space:]]*(.*)[[:space:]]*,[[:space:]]*(.*)[[:space:]]*"
-#define REGEX_TIMER  "[[:space:]]*([^[:space:]]+)[[:space:]]*,[[:space:]]*([[:digit:]]*)[[:space:]]*,[[:space:]]*([[:digit:]]*)[[:space:]]*$|[[:space:]]*([^[:space:]]+)[[:space:]]*,[[:space:]]*(cancel|pause|continue)"
-#define REGEX_MAKE   "[[:space:]]*(remote|mode|var)[[:space:]]*,[[:space:]]*(.*)[[:space:]]*|[[:space:]]*(exit|flush|disconnect|none)[[:space:]]*"
+#define REGEX_GET    "[[:space:]]*(screen_size|cover_size|model|version|cursor|ping|password)[[:space:]]*|[[:space:]]*(is_exists)[[:space:]]*,[[:space:]]*(.*)[[:space:]]*,[[:space:]]*(.*)[[:space:]]*"
+#define REGEX_TIMER  "[[:space:]]*([^[:space:]]+)[[:space:]]*,[[:space:]]*([[:digit:]]*)[[:space:]]*,[[:space:]]*([[:digit:]]*)[[:space:]]*$|[[:space:]]*([^[:space:]]+)[[:space:]]*,[[:space:]]*(cancel|pause|reset|restart|continue)"
+#define REGEX_MAKE   "[[:space:]]*(remote|mode|var)[[:space:]]*,[[:space:]]*(.*)[[:space:]]*|[[:space:]]*(exit|flush|stop|disconnect|none)[[:space:]]*"
 
 #define REGEX_SET_TL "[[:space:]]*(fg|bg|font|select)[[:space:]]*,(.*)|[[:space:]]*(add|replace)[[:space:]]*,[[:space:]]*([^[:space:]]{1}[^,]*[^[:space:]]{1})[[:space:]]*,[[:space:]]*(.*)|[[:space:]]*(close)[[:space:]]*,[[:space:]]*(clear)[[:space:]]*|[[:space:]]*(clear|close|show)[[:space:]]*"
 #define REGEX_SET_MN "[[:space:]]*(add|replace)[[:space:]]*,(.*)|[[:space:]]*(clear)[[:space:]]*"
-#define REGEX_SET_WM "[[:space:]]*(icon|window)[[:space:]]*,(.*)|[[:space:]]*(remove_all|show|close|cursor|nocursor|dynamic_cursor)[[:space:]]*|[[:space:]]*(set_cursor),[[:space:]]*(.*)[[:space:]]*"
+#define REGEX_SET_WM "[[:space:]]*(icon|window)[[:space:]]*,(.*)|[[:space:]]*(remove_all|clear_cache|show|close|cursor|nocursor|dynamic_cursor)[[:space:]]*|[[:space:]]*(set_cursor),[[:space:]]*(.*)[[:space:]]*"
 #define REGEX_SET_FM "[[:space:]]*(add|replace|select)[[:space:]]*,[[:space:]]*(left|right)[[:space:]]*,[[:space:]]*(.*)|[[:space:]]*(close|show)[[:space:]]*"
 #define REGEX_SET_VR "^[[:space:]]*([^,]*)[[:space:]]*,[[:space:]]*(.*)[[:space:]]*"
 
@@ -88,6 +88,7 @@ CONF conf = { 0, 		// Log
 	      NULL,             // Cfg. dir
 	      -1,		// Front-end port    
 	      0,		// Work with anyremote2html
+	      0,		// Ask password ?
 	      "anyRemote",      // Service name
 	      0,		// set uid
 	      0};        	// set gid
@@ -254,6 +255,8 @@ int parse_opts(int argc, char *argv[])
 		} else if (strcmp(argv[i],"-name")==0) {
                         strncpy(conf.serviceName, argv[++i],MTEXTLEN-1);
 			conf.serviceName[MTEXTLEN-1] = '\0';
+		} else if (strcmp(argv[i],"-password")==0) {
+                        conf.pass = 1;
 		} else if (strcmp(argv[i],"-f")==0) {
 			++i;
 			continue;   // already processed this parameter
@@ -429,7 +432,6 @@ char* id2Cmd (int cmdId)
 		case ID_EXIT:		    return CMD_EXIT;
 		case ID_EXEC:		    return CMD_EXEC;
 		case ID_SENDCKPD:	    return CMD_SENDCKPD;
-		case ID_SETMODE:	    return CMD_SETMODE;
 		case ID_SET:		    return CMD_SET;
 		case ID_EXECSET:	    return CMD_EXECSET;
 		case ID_TIMER:  	    return CMD_TIMER;
@@ -455,8 +457,6 @@ static int cmd2id (char *name)
         	return ID_EXEC;
         } else if (strcmp(name,CMD_SENDCKPD) == 0) {
       		return ID_SENDCKPD;
-        } else if (strcmp(name,CMD_SETMODE) == 0) {
-		return ID_SETMODE;
         } else if (strcmp(name,CMD_SET) == 0) {
 		return ID_SET;
         } else if (strcmp(name,CMD_EXECSET) == 0) {
@@ -1046,7 +1046,7 @@ static int storeExecAndSetCmd(cmdItem* ci, char *cmd, int execFlag)
 							strncat(ci->descr,start2 + result2[2].rm_so, le);
                                                 }
                                         
-                                        } else if (result2[3].rm_so >= 0) {	// clear or show|remove_all|close|cursor|nocursor|dynamic_cursor
+                                        } else if (result2[3].rm_so >= 0) {	// clear or show|remove_all|clear_cache|close|cursor|nocursor|dynamic_cursor
 
                                                 l2 = result2[3].rm_eo - result2[3].rm_so;
                                                 ci->descr = (char*) calloc(1, l + l2 + 2);
@@ -1266,9 +1266,6 @@ int storeCmds(cmdItem** cmdList, char *value)
 			start +=result->rm_eo;        
 			continue;
 		}
-		if (cmdId == ID_SETMODE ) {
-			printf("Warning: SetMode() command is deprecated !\n");
-		}
 		
 		/*if (cmds != NULL) {
 		    printf("Got command body >%s<\n",cmds);
@@ -1480,6 +1477,15 @@ static void loadInternal()
 	char cmd[] = "_GET_ICON_($$)";
 	char val[] = "ExecAndSet(image,icon,echo \'UF=\"$(CfgDir)/Icons/$(Index)/$(Param).png\";echo \"$(Param),$UF\"\'|bash -f -s);";
 	storeKey(internalMode, &(internalMode->keys),cmd,val);
+	
+	char cmd2[] = "_PING_";
+	char val2[] = "Get(ping)";
+	storeKey(internalMode, &(internalMode->keys),cmd2,val2);
+	
+	/*
+	char cmd3[] = "_PASSWORD_INVALID_";
+	char val3[] = "Set(disconnect);Make(disconnect);Make(stop);";
+	storeKey(internalMode, &(internalMode->keys),cmd3,val3);*/
 }
 
 static int loadAliases(FILE *fp)
