@@ -74,6 +74,11 @@
 #define SAME 	    	99
 #define PAUSE_STR   	"PAUSE"
 
+#define ID_EVT_INIT	      1 	     
+#define ID_EVT_EXIT	      2 	     
+#define ID_EVT_CONNECT        3 	     
+#define ID_EVT_DISCONNECT     4 	     
+
 #define EVT_INIT     	"(Init)"
 #define EVT_EXIT        "(Exit)"
 #define EVT_CONNECT     "(Connect)"
@@ -88,23 +93,21 @@
 #define ID_EXIT    	1
 #define ID_EXEC         2
 #define ID_SENDCKPD     3
-#define ID_SETMODE      4
-#define ID_SET          5
-#define ID_EXECSET      6
-#define ID_TIMER        7
-#define ID_SEND         8
-#define ID_EXECSEND     9
-#define ID_MACRO        10
-#define ID_LOAD         11
-#define ID_INCLUDE      12
-#define ID_GET          13
-#define ID_MAKE         14
-#define ID_EMU          15
+#define ID_SET          4
+#define ID_EXECSET      5
+#define ID_TIMER        6
+#define ID_SEND         7
+#define ID_EXECSEND     8
+#define ID_MACRO        9
+#define ID_LOAD         10
+#define ID_INCLUDE      11
+#define ID_GET          12
+#define ID_MAKE         13
+#define ID_EMU          14
 
 #define CMD_EXIT    	        "Exit"
 #define CMD_EXEC                "Exec"
 #define CMD_SENDCKPD            "SendCKPD"     		// AT mode only
-#define CMD_SETMODE	        "SetMode"	// ??? DEPRECATED
 #define CMD_SET                 "Set"          		// Server mode only
 #define CMD_EXECSET             "ExecAndSet"           	// Server mode only
 #define CMD_TIMER               "Timer"
@@ -141,6 +144,7 @@
 #define MAKE_DISCONN    "disconnect"
 #define MAKE_MODE       "mode"
 #define MAKE_FLUSH      "flush"
+#define MAKE_STOP       "stop"
 #define MAKE_REMOTE     "remote"
 #define MAKE_VAR        "var"
 #define MAKE_EXIT       "exit"
@@ -217,7 +221,7 @@ typedef struct Mt
 
 typedef struct Cp
 {
-	char       index[4];
+	char       index[6];
         char       value[MAXARGLEN];
 } cmdParams;
 
@@ -238,6 +242,7 @@ typedef struct
         char* cfgDir;
         int   frontEnd;
         int   http;
+        int   pass;
         char  serviceName[MTEXTLEN];
         uid_t   uid;
 	gid_t   gid;
